@@ -1,10 +1,11 @@
-// Sugarscape in Swarm. Copyright (C) 1997-1998 Nelson Minar
+// Sugarscape in Swarm. Copyright  1997-1998 Nelson Minar
 // This program is distributed without any warranty; without even the
 // implied warranty of merchantability or fitness for a particular purpose.
 // See file LICENSE for details and terms of copying.
 
 #import "ObserverSwarm.h"
 #import <simtoolsgui.h>
+#import <simtools.h> // ObjectLoader
 
 @implementation ObserverSwarm
 
@@ -180,7 +181,7 @@
       SET_WINDOW_GEOMETRY_RECORD_NAME (wealthHistogram);
       [wealthHistogram setTitle: "Agent wealth distribution"];
       [wealthHistogram setAxisLabelsX: "wealth" Y: "number of agents"];
-      [wealthHistogram setBinNum: 9];
+      [wealthHistogram setBinCount: 9];
       [wealthHistogram setLowerBound: 0];
       [wealthHistogram setUpperBound: 300];
       [wealthHistogram setCollection: agentList];
