@@ -12,7 +12,7 @@
 
 @interface Shuffler: SwarmObject
 {
-  id <UniformInteger> uniformRandom;
+  id <UniformIntegerDist> uniformRandom;
 }
 
 - setUniformRandom: rnd;
