@@ -12,5 +12,4 @@ m <- matrix (v, nrow=50, byrow=TRUE)
 maxSugarDiscrete2d <-list(lattice=m)
 attr(maxSugarDiscrete2d, "type") <- "Discrete2d"
 
-# Save the matrix with key `space' to the file `sss.hdf'.
-hdf5save ("sss.hdf", maxSugarDiscrete2d)
+hdf5save ("sss.hdf", "maxSugarDiscrete2d")
